==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/it.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Riservatezza",
    "-" : "-",
    "Add external admin" : "Aggiungi amministratore esterno",
    "Your files are not protected by encryption." : "I tuoi file non sono protetti con la cifratura.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "I tuoi file sono cifrati con la. {linkopen}cifratura lato server ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Questo server è protetto con la cifratura completa del disco.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "I tuoi file sono cifrati con la. {linkopen}cifratura lato server ↗{linkclose}. In aggiunta, questo server è protetto con la cifratura completa del disco.",
    "This server is using full-disk-encryption." : "Questo server utilizzar la cifratura completa del disco.",
    "Your data is located in: " : "I tuoi dati si trovano in:",
    "The admin hasn't selected the location of the server yet." : "L'amministratore non ha ancora selezionato la posizione del server.",
    "Please select a country" : "Seleziona una nazione",
    "You don't have any shares with individual users." : "Non hai alcuna condivisione con singoli utenti.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "Emirati Arabi Uniti",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegowina" : "Bosnia ed Erzegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgio",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brasile",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorussia",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Democratic Republic of the Congo" : "Repubblica Democratica del Congo",
    "Central African Republic" : "Repubblica Centrafricana",
    "Congo" : "Congo",
    "Switzerland" : "Svizzera",
    "Cote d'Ivoire" : "Costa d'Avorio",
    "Chile" : "Cile",
    "Cameroon" : "Camerun",
    "China" : "Cina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Cipro",
    "Czech" : "Repubblica Ceca",
    "Germany" : "Germania",
    "Djibouti" : "Gibuti",
    "Denmark" : "Danimarca",
    "Dominican Republic" : "Repubblica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egitto",
    "West Sahara" : "Sahara occidentale",
    "Eritrea" : "Eritrea",
    "Spain" : "Spagna",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Figi",
    "Falkland Islands" : "Isole Falkland",
    "France" : "Francia",
    "Gabon" : "Gabon",
    "United Kingdom" : "Regno Unito",
    "Georgia" : "Georgia",
    "Ghana" : "Ghana",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Guinea Equatoriale",
    "Greece" : "Grecia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Croazia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungheria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israele",
    "India" : "India",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islanda",
    "Italy" : "Italia",
    "Jamaica" : "Giamaica",
    "Jordan" : "Giordania",
    "Japan" : "Giappone",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirghizistan",
    "Cambodia" : "Cambogia",
    "North Korea" : "Corea del Nord",
    "South Korea" : "Corea del Sud",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kazakistan",
    "Laos" : "Laos",
    "Lebanon" : "Libano",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Lussemburgo",
    "Latvia" : "Lettonia",
    "Libya" : "Libia",
    "Morocco" : "Marocco",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauritania",
    "Malawi" : "Malawi",
    "Mexico" : "Messico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambico",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nuova Caledonia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Paesi Bassi",
    "Norway" : "Norvegia",
    "Nepal" : "Nepal",
    "New Zealand" : "Nuova Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Perù",
    "Papua New Guinea" : "Papua Nuova Guinea",
    "Philippines" : "Filippine",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonia",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portogallo",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Russia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Isole Salomone",
    "Sudan" : "Sudan",
    "Sweden" : "Svezia",
    "Singapore" : "Singapore",
    "Slovenia" : "Slovenia",
    "Slovakia" : "Slovacchia",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan del Sud",
    "El Salvador" : "El Salvador",
    "Syria" : "Siria",
    "Swaziland" : "Swaziland",
    "Chad" : "Ciad",
    "Fr. S. Antarctic Lands" : "Terre australi e antartiche francesi",
    "Togo" : "Togo",
    "Thailand" : "Thailandia",
    "Tajikistan" : "Tagikistan",
    "Timor-Leste" : "Timor Est",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turchia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucraina",
    "Uganda" : "Uganda",
    "United States" : "Stati Uniti d'America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Yemen",
    "South Africa" : "Sudafrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Il tuo account Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "I tuoi dati rappresentano chi sei e possono essere facilmente abusati. Noi di Nextcloud riteniamo che tu abbia il diritto di decidere cosa succede ai tuoi dati. Nextcloud protegge i tuoi diritti come definito nel Manifesto dei Dati Utente!",
    "User Data Manifesto 2.0" : "Manifesto dei dati utente 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definire i diritti fondamentali delle persone per controllare i propri dati nell'era di internet",
    "Control" : "Controllo",
    "over user data access" : "sull'accesso ai dati utente",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "I dati caricati esplicitamente e volontariamente da un utente devono essere sotto il controllo totale dell'utente. Gli utenti dovrebbero poter decidere a chi concedere l'accesso diretto ai propri dati e con quali permessi e licenze tale accesso dovrebbe essere concesso.",
    "Knowledge" : "Conoscenza",
    "of how the data is stored" : "di come i dati vengono archiviati",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quando i dati vengono inviati a uno specifico fornitore di servizi, gli utenti dovrebbero essere informati su dove lo specifico fornitore di servizi memorizza i dati, per quanto tempo, in quale giurisdizione opera lo specifico fornitore di servizi e quali leggi sono applicabili.",
    "Freedom" : "Libertà",
    "to choose a platform" : "di scegliere una piattaforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Gli utenti dovrebbero sempre poter estrarre i propri dati dal servizio in qualsiasi momento senza che si verifichi un blocco dal fornitore. Per garantire ciò sono necessari standard aperti per formati e protocolli.",
    "Learn more ↗" : "Ulteriori informazioni ↗",
    "Where is your data?" : "Dove sono i tuoi dati?",
    "Who has access to your data?" : "Chi ha accesso ai tuoi dati?",
    "Administrators" : "Amministratori",
    "People you shared with" : "Persone con cui hai condiviso",
    "Privacy policy" : "Criterio di riservatezza",
    "Read the privacy policy." : "Leggi subito i criteri di riservatezza.",
    "Encryption" : "Cifratura"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/it.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Riservatezza",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Il centro della riservatezza ti mostra dove sono archiviati i tuoi dati e chi può accedervi, perché li hai condivisi con loro o perché sono amministratori.",
    "Remove external admin" : "Rimuovi amministratore esterno",
    "Add external admin" : "Aggiungi amministratore esterno",
    "Your files are not protected by encryption." : "I tuoi file non sono protetti con la cifratura.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "I tuoi file sono cifrati con la. {linkopen}cifratura lato server ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Questo server è protetto con la cifratura completa del disco.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "I tuoi file sono cifrati con la. {linkopen}cifratura lato server ↗{linkclose}. In aggiunta, questo server è protetto con la cifratura completa del disco.",
    "This server is using full-disk-encryption." : "Questo server utilizzar la cifratura completa del disco.",
    "Change data location" : "Cambia posizione dei dati",
    "Your data is located in: " : "I tuoi dati si trovano in:",
    "The admin hasn't selected the location of the server yet." : "L'amministratore non ha ancora selezionato la posizione del server.",
    "Please select a country" : "Seleziona una nazione",
    "You don't have any shares with individual users." : "Non hai alcuna condivisione con singoli utenti.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "Emirati Arabi Uniti",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegowina" : "Bosnia ed Erzegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgio",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brasile",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorussia",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Democratic Republic of the Congo" : "Repubblica Democratica del Congo",
    "Central African Republic" : "Repubblica Centrafricana",
    "Congo" : "Congo",
    "Switzerland" : "Svizzera",
    "Cote d'Ivoire" : "Costa d'Avorio",
    "Chile" : "Cile",
    "Cameroon" : "Camerun",
    "China" : "Cina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Cipro",
    "Czech" : "Repubblica Ceca",
    "Germany" : "Germania",
    "Djibouti" : "Gibuti",
    "Denmark" : "Danimarca",
    "Dominican Republic" : "Repubblica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egitto",
    "West Sahara" : "Sahara occidentale",
    "Eritrea" : "Eritrea",
    "Spain" : "Spagna",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Figi",
    "Falkland Islands" : "Isole Falkland",
    "France" : "Francia",
    "Gabon" : "Gabon",
    "United Kingdom" : "Regno Unito",
    "Georgia" : "Georgia",
    "Ghana" : "Ghana",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Guinea Equatoriale",
    "Greece" : "Grecia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Croazia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungheria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israele",
    "India" : "India",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islanda",
    "Italy" : "Italia",
    "Jamaica" : "Giamaica",
    "Jordan" : "Giordania",
    "Japan" : "Giappone",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirghizistan",
    "Cambodia" : "Cambogia",
    "North Korea" : "Corea del Nord",
    "South Korea" : "Corea del Sud",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kazakistan",
    "Laos" : "Laos",
    "Lebanon" : "Libano",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Lussemburgo",
    "Latvia" : "Lettonia",
    "Libya" : "Libia",
    "Morocco" : "Marocco",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauritania",
    "Malawi" : "Malawi",
    "Mexico" : "Messico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambico",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nuova Caledonia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Paesi Bassi",
    "Norway" : "Norvegia",
    "Nepal" : "Nepal",
    "New Zealand" : "Nuova Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Perù",
    "Papua New Guinea" : "Papua Nuova Guinea",
    "Philippines" : "Filippine",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonia",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portogallo",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Russia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Isole Salomone",
    "Sudan" : "Sudan",
    "Sweden" : "Svezia",
    "Singapore" : "Singapore",
    "Slovenia" : "Slovenia",
    "Slovakia" : "Slovacchia",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan del Sud",
    "El Salvador" : "El Salvador",
    "Syria" : "Siria",
    "Swaziland" : "Swaziland",
    "Chad" : "Ciad",
    "Fr. S. Antarctic Lands" : "Terre australi e antartiche francesi",
    "Togo" : "Togo",
    "Thailand" : "Thailandia",
    "Tajikistan" : "Tagikistan",
    "Timor-Leste" : "Timor Est",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turchia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucraina",
    "Uganda" : "Uganda",
    "United States" : "Stati Uniti d'America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Yemen",
    "South Africa" : "Sudafrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Il tuo account Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "I tuoi dati rappresentano chi sei e possono essere facilmente abusati. Noi di Nextcloud riteniamo che tu abbia il diritto di decidere cosa succede ai tuoi dati. Nextcloud protegge i tuoi diritti come definito nel Manifesto dei dati utente!",
    "User Data Manifesto 2.0" : "Manifesto dei dati utente 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definire i diritti fondamentali delle persone per controllare i propri dati nell'era di internet",
    "Control" : "Controllo",
    "over user data access" : "sull'accesso ai dati utente",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "I dati caricati esplicitamente e volontariamente da un utente devono essere sotto il controllo totale dell'utente. Gli utenti dovrebbero poter decidere a chi concedere l'accesso diretto ai propri dati e con quali permessi e licenze tale accesso dovrebbe essere concesso.",
    "Knowledge" : "Conoscenza",
    "of how the data is stored" : "di come i dati vengono archiviati",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quando i dati vengono inviati a uno specifico fornitore di servizi, gli utenti dovrebbero essere informati su dove lo specifico fornitore di servizi memorizza i dati, per quanto tempo, in quale giurisdizione opera lo specifico fornitore di servizi e quali leggi sono applicabili.",
    "Freedom" : "Libertà",
    "to choose a platform" : "di scegliere una piattaforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Gli utenti dovrebbero sempre poter estrarre i propri dati dal servizio in qualsiasi momento senza che si verifichi un blocco dal fornitore. Per garantire ciò sono necessari standard aperti per formati e protocolli.",
    "Learn more ↗" : "Ulteriori informazioni ↗",
    "Where is your data?" : "Dove sono i tuoi dati?",
    "Who has access to your data?" : "Chi ha accesso ai tuoi dati?",
    "Administrators" : "Amministratori",
    "People you shared with" : "Persone con cui hai condiviso",
    "Privacy policy" : "Criterio di riservatezza",
    "Read the privacy policy." : "Leggi subito i criteri di riservatezza.",
    "Encryption" : "Cifratura"
},
"nplurals=2; plural=(n != 1);");
